package SPVM::Net::SSLeay::Error;



1;

=head1 Name

SPVM::Net::SSLeay::Error - OpenSSL Error

=head1 Description

Net::SSLeay::Error class in L<SPVM> represents an OpenSSL error.

=head1 Usage

  use Net::SSLeay::Error;

=head1 Super Class

L<Error|SPVM::Error>

=head1 Copyright & License

Copyright (c) 2024 Yuki Kimoto

MIT License

